@@ -37,7 +37,8 @@ class TestEventByBuildingApi:
             assert ret.status_code == 201
             ret_val = ret.json
             ebb_1_id = ret_val.pop("id")
-            ebb_1_etag = ret.headers["ETag"]
+            assert ret_val.pop("site")["name"] == "Site 1"
+            assert ret_val.pop("building")["name"] == "Building 1"
             assert ret_val == ebb_1
 
             # POST violating unique constraint
@@ -66,9 +67,10 @@ class TestEventByBuildingApi:
             # GET by id
             ret = client.get(f"{EVENTS_BY_BUILDINGS_URL}{ebb_1_id}")
             assert ret.status_code == 200
-            assert ret.headers["ETag"] == ebb_1_etag
             ret_val = ret.json
             ret_val.pop("id")
+            assert ret_val.pop("site")["name"] == "Site 1"
+            assert ret_val.pop("building")["name"] == "Building 1"
             assert ret_val == ebb_1
 
             # POST
