@@ -37,7 +37,10 @@ class TestEventBySpaceApi:
             assert ret.status_code == 201
             ret_val = ret.json
             ebs_1_id = ret_val.pop("id")
-            ebs_1_etag = ret.headers["ETag"]
+            assert ret_val.pop("site")["name"] == "Site 1"
+            assert ret_val.pop("building")["name"] == "Building 1"
+            assert ret_val.pop("storey")["name"] == "Storey 1"
+            assert ret_val.pop("space")["name"] == "Space 1"
             assert ret_val == ebs_1
 
             # POST violating unique constraint
@@ -66,9 +69,12 @@ class TestEventBySpaceApi:
             # GET by id
             ret = client.get(f"{EVENTS_BY_SPACES_URL}{ebs_1_id}")
             assert ret.status_code == 200
-            assert ret.headers["ETag"] == ebs_1_etag
             ret_val = ret.json
             ret_val.pop("id")
+            assert ret_val.pop("site")["name"] == "Site 1"
+            assert ret_val.pop("building")["name"] == "Building 1"
+            assert ret_val.pop("storey")["name"] == "Storey 1"
+            assert ret_val.pop("space")["name"] == "Space 1"
             assert ret_val == ebs_1
 
             # POST
@@ -154,17 +160,13 @@ class TestEventBySpaceApi:
             # GET by id
             ret = client.get(f"{EVENTS_BY_SPACES_URL}{ebs_1_id}")
             assert ret.status_code == 200
-            ebs_1_etag = ret.headers["ETag"]
 
             # GET by id not in campaign scope
             ret = client.get(f"{EVENTS_BY_SPACES_URL}{ebs_2_id}")
             assert ret.status_code == 403
 
             # DELETE
-            ret = client.delete(
-                f"{EVENTS_BY_SPACES_URL}{ebs_1_id}",
-                headers={"If-Match": ebs_1_etag},
-            )
+            ret = client.delete(f"{EVENTS_BY_SPACES_URL}{ebs_1_id}")
             assert ret.status_code == 204
 
             # POST
